Command Line Interface
======================
pubquiz automatically installs the command :code:`pubquiz`. See
:code:`pubquiz --help` for usage details.

.. click:: pubquiz.cli:main
   :prog: pubquiz
   :show-nested:
